#[repr(i32)]
pub enum halide_error_code_t {
Show variants
halide_error_code_success,
halide_error_code_generic_error,
halide_error_code_explicit_bounds_too_small,
halide_error_code_bad_type,
halide_error_code_access_out_of_bounds,
halide_error_code_buffer_allocation_too_large,
halide_error_code_buffer_extents_too_large,
halide_error_code_constraints_make_required_region_smaller,
halide_error_code_constraint_violated,
halide_error_code_param_too_small,
halide_error_code_param_too_large,
halide_error_code_out_of_memory,
halide_error_code_buffer_argument_is_null,
halide_error_code_debug_to_file_failed,
halide_error_code_copy_to_host_failed,
halide_error_code_copy_to_device_failed,
halide_error_code_device_malloc_failed,
halide_error_code_device_sync_failed,
halide_error_code_device_free_failed,
halide_error_code_no_device_interface,
halide_error_code_matlab_init_failed,
halide_error_code_matlab_bad_param_type,
halide_error_code_internal_error,
halide_error_code_device_run_failed,
halide_error_code_unaligned_host_ptr,
halide_error_code_bad_fold,
halide_error_code_fold_factor_too_small,
halide_error_code_requirement_failed,
halide_error_code_buffer_extents_negative,
halide_error_code_unused_29,
halide_error_code_unused_30,
halide_error_code_specialize_fail,
halide_error_code_device_wrap_native_failed,
halide_error_code_device_detach_native_failed,
halide_error_code_host_is_null,
halide_error_code_bad_extern_fold,
halide_error_code_device_interface_no_device,
halide_error_code_host_and_device_dirty,
halide_error_code_buffer_is_null,
halide_error_code_device_buffer_copy_failed,
halide_error_code_device_crop_unsupported,
halide_error_code_device_crop_failed,
halide_error_code_incompatible_device_interface,
halide_error_code_bad_dimensions,
halide_error_code_device_dirty_with_no_device_support,
}
halide_error_code_host_and_device_dirty
Formats the value using the given formatter. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
#[must_use]
pub fn ne(&self, other: &Rhs) -> bool1.0.0[src]
This method tests for !=.
impl<T> Any for T where
T: 'static + ?Sized, [src]
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>, [src]
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
recently added
Uses borrowed data to replace owned data, usually by cloning. Read more
impl<T, U> TryFrom<U> for T where
U: Into<T>, [src]
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.