#[repr(C)]
pub union halide_scalar_value_t__bindgen_ty_1 {
pub b: bool,
pub i8_: i8,
pub i16_: i16,
pub i32_: i32,
pub i64_: i64,
pub u8_: u8,
pub u16_: u16,
pub u32_: u32,
pub u64_: u64,
pub f32_: f32,
pub f64_: f64,
pub handle: *mut c_void,
}handle: *mut c_voidimpl<T> Any for T where
T: 'static + ?Sized, [src]
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>, [src]
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
recently added
Uses borrowed data to replace owned data, usually by cloning. Read more
impl<T, U> TryFrom<U> for T where
U: Into<T>, [src]
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.