[−][src]Struct halide_runtime::Type
Type is used to define the type of pixel data in terms of kind and bits For example, Type::new(Kind::UInt, 8) uses one 8-bit unsigned integer per channel and Type::new(Kind::Float, 32) uses a float per channel, etc...
Methods
impl Type[src]
pub fn new(kind: Kind, bits: u8) -> Type[src]
pub fn new_with_lanes(kind: Kind, bits: u8, lanes: u16) -> Type[src]
pub fn bits(&self) -> u8[src]
pub fn kind(&self) -> Kind[src]
pub fn size(&self) -> usize[src]